/********************************************************************************
** Form generated from reading UI file 'levelsetwidget.ui'
**
** Created by: Qt User Interface Compiler version 6.11.2
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_LEVELSETWIDGET_H
#define UI_LEVELSETWIDGET_H

#include <KNSWidgets/Button>
#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QListWidget>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_LevelSetWidget
{
public:
    QVBoxLayout *mainLayout;
    QLabel *label;
    QListWidget *m_lwLevelSets;
    QHBoxLayout *horizontalLayout;
    QSpacerItem *horizontalSpacer;
    KNSWidgets::Button *m_pbNewStuff;
    QSpacerItem *verticalSpacer;

    void setupUi(QWidget *LevelSetWidget)
    {
        if (LevelSetWidget->objectName().isEmpty())
            LevelSetWidget->setObjectName("LevelSetWidget");
        LevelSetWidget->resize(400, 215);
        mainLayout = new QVBoxLayout(LevelSetWidget);
        mainLayout->setContentsMargins(0, 0, 0, 0);
        mainLayout->setObjectName("mainLayout");
        label = new QLabel(LevelSetWidget);
        label->setObjectName("label");

        mainLayout->addWidget(label);

        m_lwLevelSets = new QListWidget(LevelSetWidget);
        m_lwLevelSets->setObjectName("m_lwLevelSets");

        mainLayout->addWidget(m_lwLevelSets);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout->addItem(horizontalSpacer);

        m_pbNewStuff = new KNSWidgets::Button(LevelSetWidget);
        m_pbNewStuff->setObjectName("m_pbNewStuff");

        horizontalLayout->addWidget(m_pbNewStuff);


        mainLayout->addLayout(horizontalLayout);

        verticalSpacer = new QSpacerItem(20, 20, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        mainLayout->addItem(verticalSpacer);


        retranslateUi(LevelSetWidget);

        QMetaObject::connectSlotsByName(LevelSetWidget);
    } // setupUi

    void retranslateUi(QWidget *LevelSetWidget)
    {
        label->setText(tr2i18n("Choose a level set to play:", nullptr));
        m_pbNewStuff->setText(tr2i18n("Download New Levels\342\200\246", nullptr));
        (void)LevelSetWidget;
    } // retranslateUi

};

namespace Ui {
    class LevelSetWidget: public Ui_LevelSetWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // LEVELSETWIDGET_H

